@@ -503,8 +503,6 @@ append_autostart_apps (GtkListStore *store, const char *path, GList **removed_ap
 
       if (!error)
 	{
-	  g_debug ("read %s", desktop_file_path);
-
 	  if (!append_app (store, desktop_file))
             {
               if (removed_apps)
@@ -558,6 +556,10 @@ spc_command_get_store ()
   g_list_foreach (removed_apps, (GFunc) g_free, NULL);
   g_list_free (removed_apps);
 
+  gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (store),
+                                        STORE_COL_NAME,
+                                        GTK_SORT_ASCENDING);
+
   return GTK_TREE_MODEL (store);
 }
 
@@ -674,7 +676,7 @@ spc_command_add_app (GtkListStore *store,
   GKeyFile *keyfile;
   char **argv;
   char *basename, *orig_filename, *filename;
-  char *name, *command, *comment, *description;
+  char *name, *command, *comment, *description, *icon;
   int argc;
   int i = 2;
 
@@ -682,6 +684,7 @@ spc_command_add_app (GtkListStore *store,
                       STORE_COL_NAME, &name,
                       STORE_COL_COMMAND, &command,
                       STORE_COL_COMMENT, &comment,
+                      STORE_COL_ICON_NAME, &icon,
                       -1);
 
   g_shell_parse_argv (command, &argc, &argv, NULL);
@@ -716,6 +719,14 @@ spc_command_add_app (GtkListStore *store,
   g_key_file_set_string (keyfile, DESKTOP_ENTRY_GROUP,
                          "Exec", command);  
 
+  if (icon == NULL)
+    {
+      icon = g_strdup (STARTUP_APP_ICON);
+    }
+  
+  g_key_file_set_string (keyfile, DESKTOP_ENTRY_GROUP,
+                         "Icon", icon);
+
   if (comment)
     g_key_file_set_string (keyfile, DESKTOP_ENTRY_GROUP,
                            "Comment", comment);  
@@ -737,7 +748,7 @@ spc_command_add_app (GtkListStore *store,
 
   gtk_list_store_set (store, iter,
                       STORE_COL_ENABLED, TRUE, 
-                      STORE_COL_ICON_NAME, STARTUP_APP_ICON, 
+                      STORE_COL_ICON_NAME, icon, 
                       STORE_COL_DESKTOP_FILE, desktop_file,
                       STORE_COL_ID, basename, 
                       STORE_COL_ACTIVATABLE, TRUE,
@@ -750,6 +761,7 @@ spc_command_add_app (GtkListStore *store,
   g_free (comment);
   g_free (description);
   g_free (basename);
+  g_free (icon);
 }
 
 void
@@ -775,10 +787,10 @@ spc_command_update_app (GtkListStore *store,
 }
 
 char *
-spc_command_get_app_description (const char *name, 
-                                                const char *comment)
+spc_command_get_app_description (const char *name,
+                                 const char *comment)
 {
-  return g_strdup_printf ("<b>%s</b>\n%s", name,
-                          (!gsm_util_text_is_blank (comment) ? 
-                           comment : _("No description")));
+  return g_markup_printf_escaped ("<b>%s</b>\n%s", name,
+                                  (!gsm_util_text_is_blank (comment) ?
+                                   comment : _("No description")));
 }
